package com.zanxiang.sdk.domain.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.zanxiang.sdk.domain.enums.AccountStatusEnum;
import com.zanxiang.sdk.domain.params.RegisterMobileParam;
import com.zanxiang.sdk.domain.params.RegisterPasswordParam;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.ToString;

import java.time.LocalDateTime;

/**
 * @author : lingfeng
 * @time : 2022-06-06
 * @description : 玩家表
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@ToString
@TableName("h_user")
public class User {

    /**
     * id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 所属渠道ID
     */
    private Long agentId;

    /**
     * 用户名
     */
    private String username;

    /**
     * 昵称
     */
    private String nickname;

    /**
     * 注册手机号
     */
    private String regMobile;

    /**
     * 注册邮箱
     */
    private String regEmail;

    /**
     * 密码
     */
    private String password;

    /**
     * 绑定邮箱
     */
    private String email;

    /**
     * 绑定手机号码
     */
    private String mobile;

    /**
     * 设备来源 mobile,android,iphone,ipad,web,pc,mac,wxapp
     */
    private String fromDevice;

    /**
     * 设备ID android 为imei ios 为idfa
     */
    private String deviceId;

    /**
     * 设备类型
     */
    private String deviceType;

    /**
     * -1 为冻结状态, 1 为试玩状态 2为正常状态
     */
    private Integer status;

    /**
     * 头像
     */
    private String avatar;

    /**
     * 渠道
     */
    private Long channel;

    /**
     * 注册时间
     */
    private LocalDateTime createTime;

    /**
     * 更改时间
     */
    private LocalDateTime updateTime;

    /**
     * 用户名密码注册
     *
     * @param param    : 注册参数
     * @param password : 密码
     */
    public User(RegisterPasswordParam param, String password) {
        this.username = param.getUsername();
        this.password = password;
        this.deviceId = param.getDeviceId();
        this.deviceType = param.getDeviceType();
        this.status = AccountStatusEnum.NORMAL_STATUS.getStatus();
        this.createTime = LocalDateTime.now();
        this.updateTime = this.createTime;
    }

    /**
     * 用户手机注册
     *
     * @param param    : 注册参数
     * @param password : 密码
     */
    public User(RegisterMobileParam param, String password) {
        this.username = param.getMobile();
        this.regMobile = param.getMobile();
        this.password = password;
        this.deviceId = param.getDeviceId();
        this.deviceType = param.getDeviceType();
        this.status = AccountStatusEnum.NORMAL_STATUS.getStatus();
        this.createTime = LocalDateTime.now();
        this.updateTime = this.createTime;
    }
}